@@ -17,6 +17,8 @@ from .do import (
     NodeInfoDO,
     NodeMetaDO, 
     NodeUserSettingDO,
+    PersistentVolumeClaimDO,
+    PersistentVolumeDO,
     PodContainerDO,
     PodDO,
     PodLogSettingDO,
@@ -24,7 +26,8 @@ from .do import (
     ResourceOSSSettingDO,
     SecretDO,
     SecretUserSettingDO,
-    ServiceDO
+    ServiceDO,
+    StorageClassDO
 )
 
 class K3SController:
@@ -356,6 +359,100 @@ class K3SController:
         self._check_error(response.status_code, info)
         return info
 
+    @exception_class_dec(max_try=1)
+    def create_storage_class(
+        self,
+        cluster_name: str,
+        storage_class: StorageClassDO,
+        timeout: int = 3
+    ):
+        data = json.dumps(storage_class.dict())
+        response = requests.post(
+            f'{self.url}/storage_class/cluster_name/{cluster_name}',
+            headers=self.header, data=data, timeout=timeout
+        )
+        info = json.loads(response.text)
+        self._check_error(response.status_code, info)
+        return info
+
+    @exception_class_dec(max_try=1)
+    def delete_storage_class(
+        self,
+        cluster_name: str,
+        storage_class_name: str,
+        timeout: int = 3
+    ):
+        response = requests.delete(
+            f'{self.url}/storage_class/cluster_name/{cluster_name}/storage_class_name/{storage_class_name}',
+            headers=self.header, timeout=timeout
+        )
+        info = json.loads(response.text)
+        self._check_error(response.status_code, info)
+        return info
+
+    @exception_class_dec(max_try=1)
+    def create_persistent_volume(
+        self,
+        cluster_name: str,
+        persistent_volume: PersistentVolumeDO,
+        timeout: int = 3
+    ):
+        data = json.dumps(persistent_volume.dict())
+        response = requests.post(
+            f'{self.url}/persistent_volume/cluster_name/{cluster_name}',
+            headers=self.header, data=data, timeout=timeout
+        )
+        info = json.loads(response.text)
+        self._check_error(response.status_code, info)
+        return info
+
+    @exception_class_dec(max_try=1)
+    def delete_persistent_volume(
+        self,
+        cluster_name: str,
+        persistent_volume_name: str,
+        timeout: int = 3
+    ):
+        response = requests.delete(
+            f'{self.url}/persistent_volume/cluster_name/{cluster_name}/persistent_volume_name/{persistent_volume_name}',
+            headers=self.header, timeout=timeout
+        )
+        info = json.loads(response.text)
+        self._check_error(response.status_code, info)
+        return info
+
+    @exception_class_dec(max_try=1)
+    def create_persistent_volume_claim(
+        self,
+        cluster_name: str,
+        persistent_volume_claim: PersistentVolumeClaimDO,
+        timeout: int = 3
+    ):
+        data = json.dumps(persistent_volume_claim.dict())
+        response = requests.post(
+            f'{self.url}/persistent_volume_claim/cluster_name/{cluster_name}',
+            headers=self.header, data=data, timeout=timeout
+        )
+        info = json.loads(response.text)
+        self._check_error(response.status_code, info)
+        return info
+
+    @exception_class_dec(max_try=1)
+    def delete_persistent_volume_claim(
+        self,
+        cluster_name: str,
+        namespace_name: str,
+        persistent_volume_claim_name: str,
+        timeout: int = 3
+    ):
+        response = requests.delete(
+            f'{self.url}/persistent_volume_claim/cluster_name/{cluster_name}/namespace_name/{namespace_name}/persistent_volume_claim_name/{persistent_volume_claim_name}',
+            headers=self.header, timeout=timeout
+        )
+        info = json.loads(response.text)
+        self._check_error(response.status_code, info)
+        return info
+
 
 repo_info = \
 {
