@@ -311,7 +311,7 @@ class VolumeSourceDO(BaseDO):
     optional: Optional[bool] = None
 
 @dataclass
-class PersistentVolumeClaimeVolumeSourceDO(BaseModel):
+class PersistentVolumeClaimeVolumeSourceDO(BaseDO):
     claim_name: str
     read_only: Optional[bool] = None
 
